<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "რედაქტირება ფორმა მიმღებთა");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "რედაქტირება ფორმა მიმღებთა");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "ფორმა Page");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "თქვენ შეუძლია შექმნას ერთზე მეტი მიმღები მიჯნავს ელ მძიმეები.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "შენახვა მიმღები ...");
define('VIEW_FORM_TABLES_HEADING', "ფორმის ცხრილის ნახვა");
define('VIEW_FORM_TABLES_BTN', "ფორმის ცხრილის ნახვა");
define('VIEW_FORM_TABLES_SELECT_TABLE', "აირჩიეთ ცხრილები");
define('VIEW_FORM_TABLES_FILTER_READ', "ფილტრის წაკითხვის შეტყობინებები");
?>